######################
######################
######################
# PRIMARY EXPERIMENT #
######################
######################
######################

rm(list = ls())
dataset <- read.csv('primary_experiment.csv')

####################
####################
# REPLICATE TABLES #
####################
####################

##########################
# Table 1: Balance Table #
##########################

checkBalanceCovs <- colnames(dataset)[!(colnames(dataset) %in% c('Treatment', 'Ramnagar', 'Contribution', 'IndianImportance'))]

# Means for the covs in the table
for(column in checkBalanceCovs){
  cat('VARIABLE NAME:', column, '\n')
  cat('Ramnagar treatment:', round(mean(dataset[[column]][dataset$Ramnagar == 1 & dataset$Treatment == 1], na.rm = TRUE), 2), '\n')
  cat('Ramnagar control:', round(mean(dataset[[column]][dataset$Ramnagar == 1 & dataset$Treatment == 0], na.rm = TRUE), 2), '\n')
  cat('Muzaffarnagar treatment:', round(mean(dataset[[column]][dataset$Ramnagar == 0 & dataset$Treatment == 1], na.rm = TRUE), 2), '\n')
  cat('Muzaffarnagar control:', round(mean(dataset[[column]][dataset$Ramnagar == 0 & dataset$Treatment == 0], na.rm = TRUE), 2), '\n')
  cat('\n')
}

# Total number of observation in each condition
cat('Ramnagar treatment:', sum(dataset$Ramnagar == 1 & dataset$Treatment == 1), '\n')
cat('Ramnagar control:', sum(dataset$Ramnagar == 1 & dataset$Treatment == 0), '\n')
cat('Muzaffarnagar treatment:', sum(dataset$Ramnagar == 0 & dataset$Treatment == 1), '\n')
cat('Muzaffarnagar control:', sum(dataset$Ramnagar == 0 & dataset$Treatment == 0), '\n')

##################################
# Table 2: Table of Main Effects #
##################################

# Separate the contribution vector into four different vector for t tests (cleaner)
Muzaffarnagar.control <- dataset$Contribution[dataset$Ramnagar == 0 & dataset$Treatment == 0]
Muzaffarnagar.treatment <- dataset$Contribution[dataset$Ramnagar == 0 & dataset$Treatment == 1]
Ramnagar.control <- dataset$Contribution[dataset$Ramnagar == 1 & dataset$Treatment == 0]
Ramnagar.treatment <- dataset$Contribution[dataset$Ramnagar == 1 & dataset$Treatment == 1]
  
# Conditional effects with t-test
t.test(Muzaffarnagar.control, Muzaffarnagar.treatment)
t.test(Ramnagar.control, Ramnagar.treatment)
t.test(Muzaffarnagar.control, Ramnagar.control)
t.test(Muzaffarnagar.treatment, Ramnagar.treatment)

# Alternatively, with Wilcoxon rank-sum test
wilcox.test(Muzaffarnagar.control, Muzaffarnagar.treatment)
wilcox.test(Ramnagar.control, Ramnagar.treatment)
wilcox.test(Muzaffarnagar.control, Ramnagar.control)
wilcox.test(Muzaffarnagar.treatment, Ramnagar.treatment)

# Difference in differences
summary(lm(Contribution ~ Treatment + Ramnagar + Treatment:Ramnagar, data = dataset))
summary(aov(Contribution ~ Treatment + Ramnagar + Treatment:Ramnagar, data = dataset))

#######################################
# Table 3: Table of Regression Output #
#######################################

lm1 <- lm(Contribution ~ Treatment, data = dataset)
lm2 <- lm(Contribution ~ Ramnagar, data = dataset)
lm3 <- lm(Contribution ~ Treatment + Ramnagar + Treatment:Ramnagar, data = dataset)
lm4 <- lm(Contribution ~ Treatment + Ramnagar + UpperCaste + Treatment:Ramnagar + Treatment:UpperCaste + Ramnagar:UpperCaste + Treatment:Ramnagar:UpperCaste, data = dataset)

#######################################
# APPENDIX TABLE: TRIPLE INTERACTIONS #
#######################################

lm5 <- lm(Contribution ~ Treatment + Ramnagar + CollegeGrad + Treatment:Ramnagar + Treatment:CollegeGrad + Ramnagar:CollegeGrad + Treatment:Ramnagar:CollegeGrad, data = dataset)
lm6 <- lm(Contribution ~ Treatment + Ramnagar + Urban + Treatment:Ramnagar + Treatment:Urban + Ramnagar:Urban + Treatment:Ramnagar:Urban, data = dataset)
lm7 <- lm(Contribution ~ Treatment + Ramnagar + Income20000 + Treatment:Ramnagar + Treatment:Income20000 + Ramnagar:Income20000 + Treatment:Ramnagar:Income20000, data = dataset)

#####################
#####################
# REPLICATE FIGURES #
#####################
#####################

#########################################################
# Figure 3: Plot of means and difference in differences #
#########################################################

# Mean contribution by condition
cat('Ramnagar treatment', mean(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 1], na.rm = TRUE), '\n')
cat('Ramnagar control', mean(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 0], na.rm = TRUE), '\n')
cat('Muzaffarnagar treatment', mean(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 1], na.rm = TRUE), '\n')
cat('Muzaffarnagar control', mean(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0], na.rm = TRUE), '\n')

##################################################################
# Figure 4: Bar plot of mean contribution by caste and condition # 
##################################################################

## Mean contribution by caste
cat('Ramnagar low caste/control', mean(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 0 & dataset$UpperCaste == 0], na.rm = TRUE), '\n')
cat('Muzaffarnagar low caste/control', mean(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0 & dataset$UpperCaste == 0], na.rm = TRUE), '\n')
cat('Ramnagar high caste/control', mean(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 0 & dataset$UpperCaste == 1], na.rm = TRUE), '\n')
cat('Muzaffarnagar high caste/control', mean(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0 & dataset$UpperCaste == 1], na.rm = TRUE), '\n')
cat('Ramnagar low caste/treatment', mean(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 1 & dataset$UpperCaste == 0], na.rm = TRUE), '\n')
cat('Muzaffarnagar low caste/treatment', mean(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 1 & dataset$UpperCaste == 0], na.rm = TRUE), '\n')
cat('Ramnagar high caste/treatment', mean(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 1 & dataset$UpperCaste == 1], na.rm = TRUE), '\n')
cat('Muzaffarnagar high caste/treatment', mean(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 1 & dataset$UpperCaste == 1], na.rm = TRUE), '\n')

####################################################################
####################################################################
# REPLICATE RESULTS MENTIONED IN TEXT BUT NOT DISPLAYED IN FIGURES #
####################################################################
####################################################################

# Section 5.2: Identity and Intragroup Status
t.test(dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 0 & dataset$UpperCaste == 0],
       dataset[['Contribution']][dataset$Ramnagar == 1 & dataset$Treatment == 0 & dataset$UpperCaste == 1])

t.test(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0 & dataset$UpperCaste == 0],
       dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0 & dataset$UpperCaste == 1])

t.test(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0 & dataset$UpperCaste == 0],
       dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 1 & dataset$UpperCaste == 0])

t.test(dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 0 & dataset$UpperCaste == 1],
       dataset[['Contribution']][dataset$Ramnagar == 0 & dataset$Treatment == 1 & dataset$UpperCaste == 1])

# Section 6: Robustness and Manipulation Check
mean(dataset$IndianImportance == 1, na.rm = TRUE)
mean(dataset$IndianImportance[dataset$Treatment == 0] == 1, na.rm = TRUE)
mean(dataset$IndianImportance[dataset$Treatment == 1] == 1, na.rm = TRUE)
wilcox.test(dataset$IndianImportance[dataset$Treatment == 0], dataset$IndianImportance[dataset$Treatment == 1])


###########################
###########################
###########################
# MANIPULATION EXPERIMENT #
###########################
###########################
###########################

rm(list = ls())
dataset <- read.csv('validation_experiment.csv')

# Linear Probability Model
summary(lm(Outcome ~ Treatment, data = dataset))

# Logit
summary(glm(Outcome ~ Treatment, family = binomial(link = "logit"), data = dataset))

# Probit
summary(glm(Outcome ~ Treatment, family = binomial(link = "probit"), data = dataset))
